@@ -804,8 +804,8 @@ class TestInvocationVariants(object):
         result = testdir.runpytest("-rf")
         lines = result.stdout.str().splitlines()
         for line in lines:
-            if line.startswith("FAIL "):
-                testid = line[5:].strip()
+            if line.startswith(("FAIL ", "FAILED ")):
+                _fail, _sep, testid = line.partition(" ")
                 break
         result = testdir.runpytest(testid, "-rf")
         result.stdout.fnmatch_lines([line, "*1 failed*"])
@@ -854,7 +854,9 @@ class TestDurations(object):
         result = testdir.runpytest("--durations=2")
         assert result.ret == 0
         lines = result.stdout.get_lines_after("*slowest*durations*")
-        assert "4 passed" in lines[2]
+        # account for the "deprecated python version" header
+        index = 2 if sys.version_info[:2] > (3, 4) else 6
+        assert "4 passed" in lines[index]
 
     def test_calls_showall(self, testdir):
         testdir.makepyfile(self.source)
