@@ -21,20 +21,6 @@ class TestCollector(object):
         assert not issubclass(Collector, Item)
         assert not issubclass(Item, Collector)
 
-    def test_compat_attributes(self, testdir, recwarn):
-        modcol = testdir.getmodulecol(
-            """
-            def test_pass(): pass
-            def test_fail(): assert 0
-        """
-        )
-        recwarn.clear()
-        assert modcol.Module == pytest.Module
-        assert modcol.Class == pytest.Class
-        assert modcol.Item == pytest.Item
-        assert modcol.File == pytest.File
-        assert modcol.Function == pytest.Function
-
     def test_check_equality(self, testdir):
         modcol = testdir.getmodulecol(
             """
@@ -950,10 +936,10 @@ def test_collect_init_tests(testdir):
         [
             "collected 2 items",
             "<Package *",
-            "  <Module '__init__.py'>",
-            "    <Function 'test_init'>",
-            "  <Module 'test_foo.py'>",
-            "    <Function 'test_foo'>",
+            "  <Module __init__.py>",
+            "    <Function test_init>",
+            "  <Module test_foo.py>",
+            "    <Function test_foo>",
         ]
     )
     result = testdir.runpytest("./tests", "--collect-only")
@@ -961,10 +947,10 @@ def test_collect_init_tests(testdir):
         [
             "collected 2 items",
             "<Package *",
-            "  <Module '__init__.py'>",
-            "    <Function 'test_init'>",
-            "  <Module 'test_foo.py'>",
-            "    <Function 'test_foo'>",
+            "  <Module __init__.py>",
+            "    <Function test_init>",
+            "  <Module test_foo.py>",
+            "    <Function test_foo>",
         ]
     )
     # Ignores duplicates with "." and pkginit (#4310).
@@ -972,11 +958,11 @@ def test_collect_init_tests(testdir):
     result.stdout.fnmatch_lines(
         [
             "collected 2 items",
-            "<Package */tests'>",
-            "  <Module '__init__.py'>",
-            "    <Function 'test_init'>",
-            "  <Module 'test_foo.py'>",
-            "    <Function 'test_foo'>",
+            "<Package */tests>",
+            "  <Module __init__.py>",
+            "    <Function test_init>",
+            "  <Module test_foo.py>",
+            "    <Function test_foo>",
         ]
     )
     # Same as before, but different order.
@@ -984,21 +970,21 @@ def test_collect_init_tests(testdir):
     result.stdout.fnmatch_lines(
         [
             "collected 2 items",
-            "<Package */tests'>",
-            "  <Module '__init__.py'>",
-            "    <Function 'test_init'>",
-            "  <Module 'test_foo.py'>",
-            "    <Function 'test_foo'>",
+            "<Package */tests>",
+            "  <Module __init__.py>",
+            "    <Function test_init>",
+            "  <Module test_foo.py>",
+            "    <Function test_foo>",
         ]
     )
     result = testdir.runpytest("./tests/test_foo.py", "--collect-only")
     result.stdout.fnmatch_lines(
-        ["<Package */tests'>", "  <Module 'test_foo.py'>", "    <Function 'test_foo'>"]
+        ["<Package */tests>", "  <Module test_foo.py>", "    <Function test_foo>"]
     )
     assert "test_init" not in result.stdout.str()
     result = testdir.runpytest("./tests/__init__.py", "--collect-only")
     result.stdout.fnmatch_lines(
-        ["<Package */tests'>", "  <Module '__init__.py'>", "    <Function 'test_init'>"]
+        ["<Package */tests>", "  <Module __init__.py>", "    <Function test_init>"]
     )
     assert "test_foo" not in result.stdout.str()
 
