@@ -18,7 +18,6 @@ from _pytest.main import EXIT_NOTESTSCOLLECTED
 from _pytest.terminal import _plugin_nameversions
 from _pytest.terminal import build_summary_stats_line
 from _pytest.terminal import getreportopt
-from _pytest.terminal import repr_pythonversion
 from _pytest.terminal import TerminalReporter
 
 DistInfo = collections.namedtuple("DistInfo", ["project_name", "version"])
@@ -361,16 +360,6 @@ class TestCollectonly(object):
         result.stdout.fnmatch_lines(["*test_fun.py: 1*"])
 
 
-def test_repr_python_version(monkeypatch):
-    try:
-        monkeypatch.setattr(sys, "version_info", (2, 5, 1, "final", 0))
-        assert repr_pythonversion() == "2.5.1-final-0"
-        sys.version_info = x = (2, 3)
-        assert repr_pythonversion() == str(x)
-    finally:
-        monkeypatch.undo()  # do this early as pytest can get confused
-
-
 class TestFixtureReporting(object):
     def test_setup_fixture_error(self, testdir):
         testdir.makepyfile(
@@ -485,7 +474,7 @@ class TestTerminalFunctional(object):
         )
         result = testdir.runpytest("-k", "test_two:", testpath)
         result.stdout.fnmatch_lines(
-            ["collected 3 items / 1 deselected", "*test_deselected.py ..*"]
+            ["collected 3 items / 1 deselected / 2 selected", "*test_deselected.py ..*"]
         )
         assert result.ret == 0
 
@@ -509,7 +498,7 @@ class TestTerminalFunctional(object):
         result = testdir.runpytest("-m", "not foo")
         result.stdout.fnmatch_lines(
             [
-                "collected 3 items / 1 deselected",
+                "collected 3 items / 1 deselected / 2 selected",
                 "*test_show_deselected.py ..*",
                 "*= 2 passed, 1 deselected in * =*",
             ]
@@ -625,7 +614,7 @@ class TestTerminalFunctional(object):
                 "*test_verbose_reporting.py::test_fail *FAIL*",
                 "*test_verbose_reporting.py::test_pass *PASS*",
                 "*test_verbose_reporting.py::TestClass::test_skip *SKIP*",
-                "*test_verbose_reporting.py::test_gen *xfail*",
+                "*test_verbose_reporting.py::test_gen *XFAIL*",
             ]
         )
         assert result.ret == 1
